summaryrefslogtreecommitdiffstats
path: root/umbrello/umbrello/classifier.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'umbrello/umbrello/classifier.cpp')
-rw-r--r--umbrello/umbrello/classifier.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/umbrello/umbrello/classifier.cpp b/umbrello/umbrello/classifier.cpp
index 167bf674..4b8e0bc0 100644
--- a/umbrello/umbrello/classifier.cpp
+++ b/umbrello/umbrello/classifier.cpp
@@ -571,7 +571,7 @@ UMLAttribute* UMLClassifier::addAttribute(const TQString &name, UMLObject *type,
bool UMLClassifier::addAttribute(UMLAttribute* att, IDChangeLog* Log /* = 0 */,
int position /* = -1 */) {
if (findChildObject(att->getName()) == NULL) {
- att->tqparent()->removeChild( att );
+ att->parent()->removeChild( att );
this->insertChild( att );
if (position >= 0 && position < (int)m_List.count())
m_List.insert(position, att);
@@ -636,10 +636,10 @@ UMLOperationList UMLClassifier::getOpList(bool includeInherited) {
for (UMLClassifierListIt pit(parents); (c = pit.current()) != NULL; ++pit) {
if (c == this) {
kError() << "UMLClassifier::getOpList: class " << c->getName()
- << " is tqparent of itself ?!?" << endl;
+ << " is parent of itself ?!?" << endl;
continue;
}
// get operations for each tqparent by recursive call
UMLOperationList pops = c->getOpList(true);
// add these operations to operation list, but only if unique.
for (UMLOperation *po = pops.first(); po; po = pops.next()) {
@@ -684,7 +684,7 @@ UMLTemplate* UMLClassifier::addTemplate(const TQString &name, Uml::IDType id) {
bool UMLClassifier::addTemplate(UMLTemplate* newTemplate, IDChangeLog* log /* = 0*/) {
TQString name = newTemplate->getName();
if (findChildObject(name) == NULL) {
- newTemplate->tqparent()->removeChild(newTemplate);
+ newTemplate->parent()->removeChild(newTemplate);
this->insertChild(newTemplate);
m_List.append(newTemplate);
emit templateAdded(newTemplate);
@@ -702,7 +702,7 @@ bool UMLClassifier::addTemplate(UMLTemplate* Template, int position)
{
TQString name = Template->getName();
if (findChildObject(name) == NULL) {
- Template->tqparent()->removeChild(Template);
+ Template->parent()->removeChild(Template);
this->insertChild(Template);
if( position >= 0 && position <= (int)m_List.count() )
m_List.insert(position,Template);
@@ -636,10 +636,10 @@ UMLOperationList UMLClassifier::getOpList(bool includeInherited) {
continue;
}
- // get operations for each tqparent by recursive call
+ // get operations for each parent by recursive call
UMLOperationList pops = c->getOpList(true);
// add these operations to operation list, but only if unique.